@@ -212,7 +212,7 @@ use strict;
 use base 'Exporter';
 use vars qw(@EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
 
-$VERSION = '0.64';
+$VERSION = '0.65';
 
 # we are just a frontend, so loop over the modules, and
 # suck up everything in @EXPORT
@@ -400,10 +400,14 @@ are currently maintained by Chris Nandor E<lt>pudge@pobox.comE<gt>.
 
 Michael Blakeley E<lt>mike@blakeley.comE<gt>,
 Emmanuel. M. Decarie E<lt>emm@scriptdigital.comE<gt>,
+Matthew Drayton E<lt>matthew@stairways.com.auE<gt>,
 brian d foy E<lt>comdog@panix.comE<gt>,
 David Hand E<lt>davidhand@davidhand.comE<gt>,
 Gero Herrmann E<lt>herr@ils.uec.ac.jpE<gt>,
+Peter N Lewis E<lt>peter@stairways.com.auE<gt>,
 Paul McCann E<lt>pmccann@maths.adelaide.edu.auE<gt>,
+Randal Schwartz E<lt>merlyn@stonehenge.comE<gt>,
+John Siracusa E<lt>siracusa@mindspring.comE<gt>,
 Dan Sugalksi E<lt>dan@sidhe.orgE<gt>,
 Ken Williams E<lt>ken@mathforum.orgE<gt>,
 Steve Zellers.
